@@ -189,8 +189,12 @@ class API:
 
         data_str = json.dumps(data)
 
+        json_result = json_query(self.proxy_vm_name, data_str, timeout)
+        if not json_result:
+            raise BaseError("No response from proxy")
+
         try:
-            result = json.loads(json_query(self.proxy_vm_name, data_str, timeout))
+            result = json.loads(json_result)
         except json.decoder.JSONDecodeError:
             raise BaseError("Error in parsing JSON")
 
@@ -336,6 +340,31 @@ class API:
         # We should never reach here
         return False
 
+    def delete_conversation(self, uuid: str) -> bool:
+        """
+        This method will delete the source's conversation.
+
+        If the UUID is not found in the server, it will raise WrongUUIDError.
+
+        :param uuid: Source UUID as string.
+        :returns: True if the operation is successful.
+        """
+
+        path_query = "api/v1/sources/{}/conversation".format(uuid)
+        method = "DELETE"
+
+        data, status_code, headers = self._send_json_request(
+            method, path_query, headers=self.req_headers, timeout=self.default_request_timeout,
+        )
+
+        if status_code == 404:
+            raise WrongUUIDError("Missing source {}".format(uuid))
+
+        if "message" in data and data["message"] == "Source data deleted":
+            return True
+
+        return False
+
     def delete_source_from_string(self, uuid: str) -> bool:
         """
         This method will delete the source and collection. If the UUID
